#!/usr/bin/fades

"""Mirror the followers in Mastodon."""

import sys
import itertools

import infoauth  # fades
from mastodon import Mastodon  # fades Mastodon.py


USER_INFO = "{display_name} ({username}): following={following_count} followers={followers_count})"


def main(filepath):
    """Main entry point."""
    auth = infoauth.load(filepath)
    mastodon = Mastodon(access_token=auth["access_token"], api_base_url="https://rebel.ar")
    account_id = mastodon.me()["id"]

    current_followers = mastodon.account_followers(account_id, limit=32767)
    current_followingto = mastodon.account_following(account_id, limit=32767)
    print("Current followers", len(current_followers))
    print("Current following to", len(current_followingto))

    all_accounts = {
        acc["id"]: acc for acc in itertools.chain(current_followingto, current_followers)
    }
    follower_ids = set(acc["id"] for acc in current_followers)
    followingto_ids = set(acc["id"] for acc in current_followingto)
    those_to_follow = follower_ids - followingto_ids
    those_to_unfollow = followingto_ids - follower_ids

    print("Following to", len(those_to_follow))
    for acc_id in those_to_follow:
        acc_info = all_accounts[acc_id]
        print("  ", USER_INFO.format_map(acc_info))
        mastodon.account_follow(acc_id)

    print("Unfollowing to", len(those_to_unfollow))
    for acc_id in those_to_unfollow:
        acc_info = all_accounts[acc_id]
        print("  ", USER_INFO.format_map(acc_info))
        mastodon.account_unfollow(acc_id)


if __name__ == "__main__":
    if len(sys.argv) != 2:
        print("USAGE: mirror-mastodon-fwers.py <filepath to infoauth secrets>")
        exit()
    main(sys.argv[1])
